require "minitest/autorun"
require File.expand_path("../../../lib/cre_property_matcher/property.rb", __FILE__)
require File.expand_path("../../../lib/cre_property_matcher/property_data_calculator.rb", __FILE__)

class TestPropertyDataCalculator < Minitest::Test
	include PropertyDataCalculator 

	def setup
		@reference = Property.new({noi: 1, ncf: 2, uw_expenses: 3, uw_revenue: 4, state: "OH", general_property_type: "Retail"})
		@properties = []
		
		states_array = ["OH", "OH", "NJ", "CT", "OH"]
		property_type_array = ["Retail", "Office", "Manufactured Housing", "Retail", "Office"]

		[1,2,3,4,5].each do |n|
			@properties << Property.new({noi: n, ncf: n, uw_expenses: n, uw_revenue: n, state: states_array[n - 1], general_property_type: property_type_array[n - 1]})
		end

		@properties
	end

	def test_get_average_for_all
		result = get_average_for_all_by_property_type(@properties, "noi", "Retail")
		assert_equal 2.5, result
	end

	def test_get_average_by_reference_property_state
		result = get_average_by_reference_property_state(@properties, @reference, "noi")
		assert_equal (8/3.0), result
	end

	def test_get_average_by_attribute
		result = get_average_by_attribute(@properties, "noi")
		assert_equal 3.0, result
	end

	def test_get_average_by_reference_property_state_and_property_type
		result = get_average_by_reference_property_state_and_property_type(@properties, @reference, "noi")
		assert_equal 1.0, result
	end
end
